@@ -31,24 +31,37 @@ class Gui : public QWidget, public Ui::Gui {
       void loadSettings();
 
      private:
-      QTimer         *timer;
-      QProcess       *process;
-      QProcess       *process2;
-      QDateTime      timeInTheFuture;
+      QTimer         *dateTimeTimer, *timer;
+      QProcess       *process1, *process2;
+      QDateTime      nextDate, timeInTheFuture;
       double         secondsToTimeInTheFuture;
-      QPlainTextEdit *hintMsgBox;
+      QTextEdit      *hintMsgBox;
+      QString        file;
+      QSettings      *settings; 
+      QString        program1, program2;
+      bool           process2Started;
 
      private slots:
+      void currentDateAndTime(); //for the current minimum date and time
       void check();       //checks if the time that was set is reached
+      void getProgram1();
+      void getProgram2();
       void run();         //runs the process
-      void output();      //prints output into a file if loggingCheckBox is checked
-      void errorOutput(); //prints errorOutput into a file if loggingCheckBox is checked
+      void output1();      //prints output into a file if loggingCheckBox is checked
+      void output2();
+      void errorOutput1(); //prints errorOutput into a file if loggingCheckBox is checked
+      void errorOutput2();
       void message();     //shows a messageBox if the process is finished, or if errors occured
       void checkForProcess2(); //if textEdit2 !=0 a second process will be started
       void shutdown_or_message(); //either shuts down the system or shows if the process is finished
       void info_hint();   //shows a InfoMessageBox
+      void saveData();
+
      signals:
       void finished();
+
+     protected:
+      virtual void closeEvent(QCloseEvent* window_close);
 };
 
 #endif
