@@ -20,7 +20,7 @@
 
 int main (int argc, char *argv[]){
 
-     QApplication app(argc,argv);
+     QApplication app(argc, argv);
      //Qt translations
      QTranslator qtTranslator;
      qtTranslator.load("qt_" + QLocale::system().name(),
@@ -28,9 +28,9 @@ int main (int argc, char *argv[]){
      app.installTranslator(&qtTranslator);
 
      //My translations
-     QString lo = ":/locale/" + QLocale::system().name();
      QTranslator translator;
-     translator.load(lo);
+     QString trDir = "/usr/share/qprogram-starter/translations/";
+     translator.load(trDir + "qprogram-starter_" + QLocale::system().name());
      app.installTranslator(&translator);
 
      Gui window;
