@@ -19,8 +19,15 @@
 #include "power.h"
 #include "preferences.h"
 #include "info.h"
+#include "calendar.h"
 
 bool timeRunning;
+bool lockMyScreen;
+extern QString fonts; //variable declared in preferences.cpp
+extern int fontS1;    // ""
+extern int fontS2;    // ""
+extern int fontS3;    // ""
+extern QDate setCalendarDate; //variable declared in calendar.cpp
 
 Gui::Gui(QWidget *parent): QWidget(parent){
 
@@ -29,6 +36,7 @@ Gui::Gui(QWidget *parent): QWidget(parent){
      finishedExecuted = false;
      timeRunning = false;
      logFileSize = 1.5;
+     lockAll = false;
 
      datetime = QDateTime::currentDateTime();
      elapsedTime.start();
@@ -38,6 +46,9 @@ Gui::Gui(QWidget *parent): QWidget(parent){
    //Preferences
      pref = new Preferences(this);
 
+   //CalendarBox
+     calendarBox = new Calendar(this);
+
    //InfoMessageBox
      infoBox = new Info(this);
 
@@ -47,8 +58,16 @@ Gui::Gui(QWidget *parent): QWidget(parent){
      horizontalSpacer4->changeSize(85,13,QSizePolicy::Maximum,QSizePolicy::Expanding);
      horizontalSpacer5->changeSize(85,13,QSizePolicy::Maximum,QSizePolicy::Expanding);
 
+   //Versioning
+     QFile versionFile(":version");
+     versionFile.open(QIODevice::ReadOnly | QIODevice::Text);
+     QTextStream in(&versionFile);
+     QString string = in.readLine();
+     version->setText(string);
+     versionFile.close();
+
    //TrayIcon
-     icon = QIcon(":/pixmap/red_glasses.xpm");
+     icon = QIcon(":red_glasses");
      TIcon = new QSystemTrayIcon(this);
      TIcon->setIcon(icon);
      TIcon->show();
@@ -106,15 +125,12 @@ Gui::Gui(QWidget *parent): QWidget(parent){
 
    //Fonts
      font1 = new QFont;
-     font1->setFamily(QString::fromUtf8("Times"));
      font1->setBold(true);
 
      font2 = new QFont;
-     font2->setFamily(QString::fromUtf8("Times"));
      font2->setBold(true);
 
      font3 = new QFont;
-     font3->setFamily(QString::fromUtf8("Times"));
 
    //Timer
      timer = new QTimer(this); //for updating countdown display and check if time is over
@@ -127,27 +143,32 @@ Gui::Gui(QWidget *parent): QWidget(parent){
      connect(comboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(power_action(int)));
      connect(power_actions, SIGNAL(triggered(QAction*)), this, SLOT(power(QAction*)));
      connect(ti, SIGNAL(timeout()), this, SLOT(showW())); //set window state for ti
-     connect(ok, SIGNAL(clicked(bool)), this, SLOT(starter())); //starts timer & stopps ti
-     connect(timer, SIGNAL(timeout()), this, SLOT(update()));    //runs update() every 10 seconds
-     connect(now, SIGNAL(clicked(bool)), this, SLOT(finished()));  //closes the program & starts the shutdown immediately
+     connect(ok, SIGNAL(clicked(bool)), this, SLOT(set())); //starts timers and time calculations
+     connect(timer, SIGNAL(timeout()), this, SLOT(updateT()));    //runs updateT() every 10 seconds
+     connect(now, SIGNAL(clicked(bool)), this, SLOT(finished()));//closes the program & starts the shutdown immediately
      connect(minim, SIGNAL(clicked(bool)), this, SLOT(showMinimized())); //minimizes window
      connect(TIcon, SIGNAL(activated(QSystemTrayIcon::ActivationReason)),
        this, SLOT(iconActivated(QSystemTrayIcon::ActivationReason))); //handles systray-symbol
      connect(pref_action, SIGNAL(triggered()), pref, SLOT(show()));
      connect(pref, SIGNAL(starting()), ti, SLOT(stop()));
      connect(pref, SIGNAL(finishing()), ti, SLOT(start())); //start the Qtimer ti if timeRunning == false
+     connect(pref, SIGNAL(changeFont()), this, SLOT(getFonts()));
      connect(reset_action, SIGNAL(triggered()), this, SLOT(reset()));
      connect(info_action, SIGNAL(triggered()), this, SLOT(setInfoText()));
      connect(info_action, SIGNAL(triggered()), infoBox, SLOT(show()));
      connect(infoBox, SIGNAL(starting()), ti, SLOT(stop()));
      connect(infoBox, SIGNAL(finishing()), ti, SLOT(start()));
+     connect(toolButton, SIGNAL(clicked(bool)), this, SLOT(showCalendarBox()));
+     connect(calendarBox, SIGNAL(aDateWasSet()), this, SLOT(setDate()));
      connect(qApp, SIGNAL(aboutToQuit()), this, SLOT(beforeQuit())); //save window size / logs and unregister qshutdown
      connect(quit_action, SIGNAL(triggered()), qApp, SLOT(quit())); //contextmenu "Quit" for the systray quits Programm
 }
 
 Gui::~Gui(){ delete font1; delete font2; delete font3; }
 
-void Gui::setInfoText(){ infoBox->setPlainText(informations); }
+void Gui::setInfoText(){ infoBox->setHtml(information); }
+
+void Gui::setDate(){ toolButton->setText(setCalendarDate.toString(Qt::SystemLocaleShortDate)); }
 
 void Gui::center(){
      QDesktopWidget *desktop = qApp->desktop();
@@ -158,10 +179,8 @@ void Gui::center(){
 
 void Gui::iconActivated(QSystemTrayIcon::ActivationReason reason){
      if(reason == QSystemTrayIcon::Trigger){
-       if(isHidden()||isMinimized()){  //in case thant the window is minimized or hidden
-         center();
+       if(isHidden()||isMinimized())  //in case thant the window is minimized or hidden
          showNormal();
-       }
        else
          hide();
      }
@@ -254,55 +273,176 @@ void Gui::keyPressEvent(QKeyEvent *kEvent){
          infoBox->show();
        }
      }
+     if(kEvent->modifiers() == Qt::ShiftModifier){
+       if(kEvent->key() == Qt::Key_E){
+      #ifdef Q_OS_WIN32
+         QString file(QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/qshutdown/qshutdown.conf");
+      #else //!Q_OS_WIN32
+         QString file(QDir::homePath() + "/.qshutdown/qshutdown.conf");
+      #endif //Q_OS_WIN32
+         QProcess editConf;
+         QString editor;
+         QString su;
+         if(QFileInfo("/usr/bin/gksudo").exists())
+           su = "gksudo";
+         else if(QFileInfo("/usr/bin/gksu").exists())
+           su = "gksu";
+         else if(QFileInfo("/usr/bin/kdesudo").exists())
+           su = "kdesudo";
+         else if(QFileInfo("/usr/bin/kdesu").exists())
+           su = "kdesu";
+         if(QFileInfo("/usr/bin/gedit").exists())
+           editor = "gedit";
+         else if(QFileInfo("/usr/bin/kate").exists())
+           editor = "kate";
+         else if(QFileInfo("/usr/bin/kwrite").exists())
+           editor = "kwrite";
+         else if(QFileInfo("/usr/bin/emacs").exists())
+           editor = "emacs";
+         editConf.start(su, QStringList() << editor << file);
+         if(editConf.waitForFinished()){
+        #ifdef Q_OS_WIN32
+           QSettings settings(file, QSettings::IniFormat);
+        #else //!Q_OS_WIN32
+           QSettings settings(file, QSettings::NativeFormat);
+        #endif //Q_OS_WIN32
+           if(settings.value("Lock_all").toBool()){
+             lockAll = true;
+             lockEverything(true);
+           }
+           else{
+             lockAll = false;
+             lockEverything(false);
+           }
+         }
+       }
+     }
 }
 
-void Gui::update(){
+void Gui::updateT(){
      if(finishedExecuted)
        reset();
-     Time();  //calculates i or rather the new time every second
 
-     if(warnings->isChecked() && (((i<=100) && (i>95)) || ((i<=40) && (i>35))) && !ti->isActive())
-       ti->start(30000);
+     QString tip1, tip2;
 
-     QString tip1, tip2, tip3;
-
-     tip1 = ("'qshutdown' - ");
      if(shutdown_action->isChecked())
-       tip2 = (tr("shutdown in "));
+       tip1 = (tr("shutdown in "));
      if(reboot_action->isChecked())
-       tip2 = (tr("reboot in "));
+       tip1 = (tr("reboot in "));
      if(suspend_action->isChecked())
-       tip2 = (tr("suspend in "));
+       tip1 = (tr("suspend in "));
      if(hibernate_action->isChecked())
-       tip2 = (tr("hibernate in "));
+       tip1 = (tr("hibernate in "));
 
-     if((i/60.0)>=60) //Display hours and minutes
-       tip3 = (QString::number(i/3600) + tr(" hours + ")
-              + QString::number(i/60 - (i/3600)*60) + tr(" minutes"));
-     else if(((i/60.0)<60) && (i>=60)) //Display only minutes
-       tip3 = (QString::number(i/60) + tr(" minutes"));
-     else if(i<60) //Display only seconds
-       tip3 = (QString::number(i) + tr(" seconds"));
-     setWindowTitle(tip1 + tip2 + tip3);
-     TIcon->setToolTip(tip2 + tip3);
-     if(i>=60){
-       lcdL->setText(tr("minutes"));
-       lcd->display(i/60);
-     }
-     else if(i<60){
-       lcdL->setText(tr("seconds"));
-       lcd->display(i);
-     }
+     if(QDate::currentDate().daysTo(setCalendarDate) >= 1)
+       toolButton->setText(setCalendarDate.toString(Qt::SystemLocaleShortDate));
 
-     //this will ensure that the shutdown-type will be executed in case a few seconds were skipped
-     if(i<=86390)
-       n = 10; //any number to keep i in check
-     if((i==0) || ((i>n) && (i>86390)))
-       finished(); //execute shutdown-type
+     if(QDate::currentDate().daysTo(setCalendarDate) > 1){ //if the date difference between today and the selected day
+                                                           //in the calendar is greater than one
+     //if more than one year
+       if(QDate::currentDate().daysTo(setCalendarDate) >= 365*2){
+         tip2 = (QString::number(QDate::currentDate().daysTo(setCalendarDate)/365) + " " + tr("years"));
+         lcdL->setText(tr("years"));
+         lcd->display(QDate::currentDate().daysTo(setCalendarDate)/365);
+       }
+       if(QDate::currentDate().daysTo(setCalendarDate) >= 365 && QDate::currentDate().daysTo(setCalendarDate) < 365*2){
+         tip2 = (">= 1 " + tr("year"));
+         lcdL->setText(tr("year"));
+         lcd->display(1);
+       }
+     //if more than one month
+       if(QDate::currentDate().daysTo(setCalendarDate) >= 30*2 && QDate::currentDate().daysTo(setCalendarDate) < 356){
+         tip2 = (QString::number(QDate::currentDate().daysTo(setCalendarDate)/30) + " " + tr("months"));
+         lcdL->setText(tr("months"));
+         lcd->display(QDate::currentDate().daysTo(setCalendarDate)/30);
+       }
+       if(QDate::currentDate().daysTo(setCalendarDate) >= 30 && QDate::currentDate().daysTo(setCalendarDate) < 30*2){
+         tip2 = (">= 1 " + tr("month"));
+         lcdL->setText(tr("month"));
+         lcd->display(1);
+       }
+     //if less than 30 days
+       if(QDate::currentDate().daysTo(setCalendarDate) < 30){
+         tip2 = (QString::number(QDate::currentDate().daysTo(setCalendarDate)) + " " + tr("days"));
+         lcdL->setText(tr("days"));
+         lcd->display(QDate::currentDate().daysTo(setCalendarDate));
+       }
+     }
+     if(QDate::currentDate().daysTo(setCalendarDate) == 1){ //if there is one more day to go
+
+       Time();
+
+       if(i>=86400){ //if one day and some time to go
+         tip2 = (">= 1 " + tr("day"));
+         lcdL->setText(tr("day"));
+         lcd->display(1);
+       }
+       if(i<86400 && i>=7200){ //if there is less than one day show hours
+         tip2 = (QString::number(i/3600) + " " + tr("hours"));
+         lcdL->setText(tr("hours"));
+         lcd->display(i/3600);
+       }
+       if(i<7200 && i>=3600){
+         tip2 = ("1 " + tr("hour"));
+         lcdL->setText(tr("hour"));
+         lcd->display(1);
+       }
+       if(i<3600 && i>=120){ //if less than one hour
+         tip2 = (QString::number(i/60) + " " + tr("minutes"));
+         lcdL->setText(tr("minutes"));
+         lcd->display(i/60);
+       }
+       if(i<60){
+         tip2 = ("1 " + tr("minute"));
+         lcdL->setText(tr("minute"));
+         lcd->display(1);
+       }
+     }
+     if(QDate::currentDate()==setCalendarDate || setCalendarDate.isNull()){ //if there was no date
+                                             //set in the calendar or the set day is the current day
+       Time();
+
+       if(warnings->isChecked() && (((i<=100) && (i>95)) || ((i<=40) && (i>35))) && !ti->isActive())
+         ti->start(30000);
+
+       if(i >= 3600){ //Display hours and minutes
+         tip2 = (QString::number(i/3600) + " " + tr("hours") + " + "
+                + QString::number(i/60 - (i/3600)*60) + " " + tr("minutes"));
+         lcdL->setText(tr("hours"));
+         lcd->display(i/3600);
+       }
+       if(i<3600 && i>=120){ //Display only minutes
+         tip2 = (QString::number(i/60) + " " + tr("minutes"));
+         lcdL->setText(tr("minutes"));
+         lcd->display(i/60);
+       }
+       if(i<120 && i>=60){
+         tip2 = ("1 " + tr("minute"));
+         lcdL->setText(tr("minute"));
+         lcd->display(1);
+       }
+       if(i<60){ //Display only seconds
+         tip2 = (QString::number(i) + " " + tr("seconds"));
+         lcdL->setText(tr("seconds"));
+         lcd->display(i);
+       }
+
+       //this will ensure that the shutdown-type will be executed in case a few seconds were skipped
+       if(i<=86390)
+         n = 10; //any number to keep i in check
+       if((i==0) || ((i>n) && (i>86390)))
+         finished(); //execute shutdown-type
+     }
+     setWindowTitle(tip1 + tip2);
+     TIcon->setToolTip(tip1 + tip2);
 }
 
 void Gui::set(){
      timeRunning = true;
+
+     ti->stop();
+     timer->start(1000);
+
      localTime = QTime::currentTime(); //the time now
      if(radio2->isChecked()) //if minute-countdown
        futureTime = localTime.addSecs(spin->value()*60); //add spinbox-value to the current time
@@ -310,36 +450,33 @@ void Gui::set(){
        futureTime = timeEdit->time(); //else the future time is the time of the timeEdit
      n = 86400; // any number bigger than i - just for initializing
 
-     if(lockAll)
-       warnings->setEnabled(true);
-
      if(lock->isChecked()){       //when OK-button is clicked and lock is checked
-       spin->setDisabled(true);             //deaktivate spinbox
-       radio1->setDisabled(true);            //deaktivate radiobutton
-       radio2->setDisabled(true);
-       lock->setDisabled(true);
-       timeEdit->setDisabled(true);
-       comboBox->setDisabled(true);
-       targetTime->setDisabled(true);
-       minutes->setDisabled(true);
+       QList<QWidget*> list;
+       list << spin << radio1 << radio2 << lock << timeEdit << comboBox << targetTime
+            << minutes;
+       foreach(QWidget * ptr, list)
+         ptr->setDisabled(true);
+       power_actions->setDisabled(true);
        ok->hide();
        minim->show();
        minim->setFocus();
        minim->setAutoDefault(true);         //minimize-button will accept the return key
-       power_actions->setDisabled(true);
      }
      showMinimized();
      if(!lockAll)
        reset_action->setVisible(true);
 }
 
-void Gui::starter(){ set(); ti->stop(); timer->start(1000); } //stops ti-Qtimer and starts timer-Qtimer
-
 void Gui::Time(){
      localTime = QTime::currentTime();
      i = localTime.secsTo(futureTime); //the difference of the localTime and the future time
+     if(radio2->isChecked() && (QDate::currentDate().daysTo(setCalendarDate) == 1))
+       i = ((23-localTime.hour())*3600 + (59-localTime.minute())*60 + spin->value()*60);
+     if(radio1->isChecked() && (QDate::currentDate().daysTo(setCalendarDate) == 1))
+       i = ((23-localTime.hour())*3600 + (59-localTime.minute())*60 + timeEdit->time().hour()*3600
+           + timeEdit->time().minute()*60);
      if(i<0)                           //if the date is on the next day
-       i = 86400 + localTime.secsTo(futureTime); //add 1 day in seconds
+       i += 86400; //add 1 day in seconds
 }
 
 void Gui::saveWindowSize(){
@@ -350,7 +487,7 @@ void Gui::saveWindowSize(){
      QString file(QDir::homePath() + "/.qshutdown/qshutdown.conf");
      QSettings settings(file, QSettings::NativeFormat);
    #endif //Q_OS_WIN32
-     settings.setValue("WindowSize/size", size());
+     settings.setValue("MainWindowSize/size", size());
 }
 
 void Gui::finished(){
@@ -425,13 +562,6 @@ void Gui::beforeQuit(){
   #endif //Q_OS_WIN32
 }
 
-void Gui::resizeEvent(QResizeEvent* window_resize){
-   #ifndef Q_OS_WIN32
-     center();
-   #endif //Q_OS_WIN32
-     QWidget::resizeEvent(window_resize);
-}
-
 void Gui::loadSettings(){
 /***************** create file and it's entries *****************/
 #ifdef Q_OS_WIN32
@@ -454,8 +584,12 @@ void Gui::loadSettings(){
        settings.setValue("Time/countdown_minutes", 60);
      if(!settings.contains("Time/countdown_at_startup"))
        settings.setValue("Time/countdown_at_startup", false);
-     if(!settings.contains("WindowSize/size"))
-       settings.setValue("WindowSize/size", QSize(430, 325));
+     if(!settings.contains("Hide_at_startup"))
+       settings.setValue("Hide_at_startup", false);
+     if(!settings.contains("MainWindowSize/size"))
+       settings.setValue("MainWindowSize/size", QSize(430, 325));
+     if(!settings.contains("Fonts/font_type"))
+       settings.setValue("Fonts/font_type", "Times New Roman");
      if(!settings.contains("Fonts/font1"))
        settings.setValue("Fonts/font1", 13);
      if(!settings.contains("Fonts/font2"))
@@ -476,11 +610,16 @@ void Gui::loadSettings(){
        settings.setValue("Logfile/logging", false);
      if(!settings.contains("Logfile/size"))
        settings.setValue("Logfile/size", 1.5);
+     if(!settings.contains("Lock_screen"))
+       settings.setValue("Lock_screen", true);
 
 /***************** read files entries *****************/
      timeEdit->setTime(QTime(settings.value("Time/time_hour").toInt(),settings.value("Time/time_minute").toInt()));
      spin->setValue(settings.value("Time/countdown_minutes").toInt());
-     resize(settings.value("WindowSize/size").toSize());
+     resize(settings.value("MainWindowSize/size").toSize());
+     font1->setFamily(settings.value("Fonts/font_type").toString());
+     font2->setFamily(settings.value("Fonts/font_type").toString());
+     font3->setFamily(settings.value("Fonts/font_type").toString());
      font1->setPointSize(settings.value("Fonts/font1").toInt());
      font2->setPointSize(settings.value("Fonts/font2").toInt());
      font3->setPointSize(settings.value("Fonts/font3").toInt());
@@ -492,33 +631,24 @@ void Gui::loadSettings(){
      log_action->setChecked(settings.value("Logfile/logging").toBool());
      logFileSize = settings.value("Logfile/size").toDouble();
 
+     if(settings.value("Time/countdown_at_startup").toBool()){
+       set();
+       if(settings.value("Hide_at_startup").toBool())
+         QTimer::singleShot(1500, this, SLOT(hide()));
+     }
+
      if(settings.value("Lock_all").toBool()){
        lockAll = true;
-       reset_action->setDisabled(true);
-       pref_action->setDisabled(true);
-       lock->setChecked(true);
-       lock->setDisabled(true);
-       radio1->setDisabled(true);
-       radio2->setDisabled(true);
-       timeEdit->setDisabled(true);
-       spin->setDisabled(true);
-       comboBox->setDisabled(true);
-       targetTime->setDisabled(true);
-       minutes->setDisabled(true);
-       quit_action->setDisabled(true);
-       log_action->setDisabled(true);
-       power_actions->setDisabled(true);
-       warnings->setDisabled(true);
+       lockEverything(true);
      }
      else
        lockAll = false;
 
-     comboBox->setFont(*font1);
-     targetTime->setFont(*font1);
-     minutes->setFont(*font1);
-     spin->setFont(*font1);
-     timeEdit->setFont(*font1);
-     lcdL->setFont(*font1);
+     QList<QWidget*> list;
+     list << lcdL << comboBox << targetTime
+          << minutes << spin << timeEdit;
+     foreach(QWidget * ptr, list)
+       ptr->setFont(*font1);
      ok->setFont(*font2);
      minim->setFont(*font2);
      warnings->setFont(*font3);
@@ -549,16 +679,48 @@ void Gui::loadSettings(){
        default:;
      }
 
-     if(settings.value("Time/countdown_at_startup").toBool()){
-       starter();
-       QTimer::singleShot(7000, this, SLOT(close()));
-     }
+     if(settings.value("Lock_screen").toBool())
+       lockMyScreen = true;
+     else
+       lockMyScreen = false;
 }
 
+void Gui::lockEverything(bool actual){
+     if(timeRunning){
+       reset_action->setVisible(true);
+       reset_action->setDisabled(actual);
+       pref_action->setDisabled(actual);
+       quit_action->setDisabled(actual);
+       log_action->setDisabled(actual);
+       toolButton->setDisabled(actual);
+     }
+     else if(!timeRunning){
+       if(actual)
+         lock->setChecked(true);
+       if(radio1->isChecked())
+         timeEdit->setDisabled(actual);
+       else
+         spin->setDisabled(actual);
+       reset_action->setDisabled(actual);
+       pref_action->setDisabled(actual);
+       quit_action->setDisabled(actual);
+       log_action->setDisabled(actual);
+       power_actions->setDisabled(actual);
+       reset_action->setVisible(false);
+       QList<QWidget*> widgetList;
+       widgetList << radio1 << radio2 << lock << comboBox << targetTime
+                  << minutes << toolButton;
+       foreach(QWidget * widgetPtr, widgetList)
+         widgetPtr->setDisabled(actual);
+     }
+}
 void Gui::reset(){
      setWindowTitle("'qshutdown'");
+     toolButton->setText("...");
      lcd->display(0);
      TIcon->setToolTip(NULL);
+     lcdL->setText(tr("minutes"));
+     setCalendarDate = QDate();
      if(finishedExecuted)
        showNormal();
      timer->stop();
@@ -568,19 +730,41 @@ void Gui::reset(){
      finishedExecuted = false;
      minim->hide();
      ok->show();
-     if(!lockAll){
-       if(radio1->isChecked())
-         timeEdit->setEnabled(true);
-       else
-         spin->setEnabled(true);
-       reset_action->setVisible(false);
-       radio1->setEnabled(true);
-       radio2->setEnabled(true);
-       lock->setEnabled(true);    
-       comboBox->setEnabled(true);
-       targetTime->setEnabled(true);
-       minutes->setEnabled(true);
-       power_actions->setEnabled(true);
-     }
+     if(!lockAll)
+       lockEverything(false);
      else loadSettings();
 }
+
+void Gui::getFonts(){
+     font1->setFamily(fonts);
+     font1->setPointSize(fontS1);
+     font2->setFamily(fonts);
+     font2->setPointSize(fontS2);
+     font3->setFamily(fonts);
+     font3->setPointSize(fontS3);
+
+     QList<QWidget*> list;
+     list << lcdL << comboBox << targetTime
+          << minutes << spin << timeEdit;
+     foreach(QWidget * ptr, list)
+       ptr->setFont(*font1);
+     ok->setFont(*font2);
+     minim->setFont(*font2);
+     warnings->setFont(*font3);
+     lock->setFont(*font3);
+     now->setFont(*font3);
+
+     resize(minimumSize());
+}
+
+void Gui::showCalendarBox(){
+     if(setCalendarDate.isNull())
+       calendarBox->calendarWidget->setSelectedDate(QDate::currentDate());
+     else
+       calendarBox->calendarWidget->setSelectedDate(setCalendarDate);
+     if(timeRunning && lock->isChecked())
+       calendarBox->calendarWidget->blockSignals(true);
+     else
+       calendarBox->calendarWidget->blockSignals(false);
+     calendarBox->show();
+}
