@@ -19,7 +19,7 @@
 
 #include <QtGui>
 
-class Info : public QPlainTextEdit{
+class Info : public QTextEdit{
      Q_OBJECT
 
     public:
@@ -31,7 +31,7 @@ class Info : public QPlainTextEdit{
      void finishing();
 
     protected:
-     virtual void showEvent(QShowEvent* show_pref);
+     virtual void showEvent(QShowEvent* show_);
      virtual void closeEvent(QCloseEvent* window_close);
 };
 
