@@ -18,6 +18,11 @@
 #include "preferences.h"
 
 extern bool timeRunning; //varibale declared in gui.cpp
+extern bool lockMyScreen; // ""
+QString fonts = "Times New Roman";
+int fontS1 = 13;
+int fontS2 = 18;
+int fontS3 = 11;
 
 Preferences::Preferences(QWidget *parent): QDialog(parent){
 
@@ -44,6 +49,12 @@ Preferences::Preferences(QWidget *parent): QDialog(parent){
 
      connect(buttonBox, SIGNAL(accepted()), this, SLOT(saveToConfFile()));
      connect(reset, SIGNAL(clicked(bool)), this, SLOT(resetSettings()));
+     connect(font1Spin, SIGNAL(valueChanged(int)), this, SLOT(fontSize1Changed(int)));
+     connect(font2Spin, SIGNAL(valueChanged(int)), this, SLOT(fontSize2Changed(int)));
+     connect(font3Spin, SIGNAL(valueChanged(int)), this, SLOT(fontSize3Changed(int)));
+     connect(fontComboBox, SIGNAL(currentIndexChanged(QString)), this, SLOT(fontChanged(QString)));
+     connect(buttonBox, SIGNAL(rejected()), this, SLOT(resetFont()));
+     connect(lockS, SIGNAL(toggled(bool)), this, SLOT(lockScreen()));
 }
 
 Preferences::~Preferences(){ delete settings; }
@@ -59,10 +70,14 @@ void Preferences::showEvent(QShowEvent* show_pref){
 }
 
 void Preferences::loadSettings(){
+     if(settings->contains("PrefWindowSize/size"))
+       resize(settings->value("PrefWindowSize/size").toSize());
      comboBox->setCurrentIndex(settings->value("Power/comboBox").toInt());
      timeEdit->setTime(QTime(settings->value("Time/time_hour").toInt(),settings->value("Time/time_minute").toInt()));
      spin->setValue(settings->value("Time/countdown_minutes").toInt());
      countdown->setChecked(settings->value("Time/countdown_at_startup").toBool());
+     hideMe->setChecked(settings->value("Hide_at_startup").toBool());
+     fontComboBox->setCurrentFont(settings->value("Fonts/font_type").toString());
      font1Spin->setValue(settings->value("Fonts/font1").toInt());
      font2Spin->setValue(settings->value("Fonts/font2").toInt());
      font3Spin->setValue(settings->value("Fonts/font3").toInt());
@@ -72,6 +87,7 @@ void Preferences::loadSettings(){
      lock->setChecked(settings->value("CheckBoxes/lock").toBool());
      warn->setChecked(settings->value("CheckBoxes/warnings").toBool());
      log->setChecked(settings->value("Logfile/logging").toBool());
+     lockS->setChecked(settings->value("Lock_screen").toBool());
 }
 
 void Preferences::saveToConfFile(){
@@ -80,7 +96,9 @@ void Preferences::saveToConfFile(){
        settings->setValue("Time/time_hour", timeEdit->time().hour());
        settings->setValue("Time/time_minute", timeEdit->time().minute());
        settings->setValue("Time/countdown_at_startup", countdown->isChecked());
+       settings->setValue("Hide_at_startup", hideMe->isChecked());
        settings->setValue("Time/countdown_minutes", spin->value());
+       settings->setValue("Fonts/font_type", fontComboBox->currentText());
        settings->setValue("Fonts/font1", font1Spin->value());
        settings->setValue("Fonts/font2", font2Spin->value());
        settings->setValue("Fonts/font3", font3Spin->value());
@@ -90,6 +108,7 @@ void Preferences::saveToConfFile(){
        settings->setValue("CheckBoxes/lock", lock->isChecked());
        settings->setValue("CheckBoxes/warnings", warn->isChecked());
        settings->setValue("Logfile/logging", log->isChecked());
+       settings->setValue("Lock_screen", lockS->isChecked());
      }
 }
 
@@ -98,7 +117,9 @@ void Preferences::resetSettings(){
        comboBox->setCurrentIndex(0);
        timeEdit->setTime(QTime(22,00));
        countdown->setChecked(false);
+       hideMe->setChecked(false);
        spin->setValue(60);
+       fontComboBox->setCurrentFont(QFont("Times New Roman"));
        font1Spin->setValue(13);
        font2Spin->setValue(18);
        font3Spin->setValue(11);
@@ -108,11 +129,38 @@ void Preferences::resetSettings(){
        lock->setChecked(true);
        warn->setChecked(true);
        log->setChecked(false);
+       lockS->setChecked(true);
      }
 }
 
+void Preferences::lockScreen(){
+     if(lockS->isChecked())
+       lockMyScreen = true;
+     else
+       lockMyScreen = false;
+}
+
 void Preferences::closeEvent(QCloseEvent* window_close){
      if(!timeRunning)
        finishing(); //sends SIGNAL finishing()
+     if(settings->isWritable())
+       settings->setValue("PrefWindowSize/size", size());
+
      QDialog::closeEvent(window_close);
 }
+
+void Preferences::fontChanged(QString font){ fonts = font; changeFont(); }
+
+void Preferences::fontSize1Changed(int f1){ fontS1 = f1; changeFont(); }
+
+void Preferences::fontSize2Changed(int f2){ fontS2 = f2; changeFont(); }
+
+void Preferences::fontSize3Changed(int f3){ fontS3 = f3; changeFont(); }
+
+void Preferences::resetFont(){
+     fonts = settings->value("Fonts/font_type").toString();
+     fontS1 = settings->value("Fonts/font1").toInt();
+     fontS2 = settings->value("Fonts/font2").toInt();
+     fontS3 = settings->value("Fonts/font3").toInt();
+     changeFont();
+}
