@@ -36,10 +36,17 @@ class Preferences : public QDialog, public Ui::Preferences {
      void loadSettings();
      void saveToConfFile();
      void resetSettings();
+     void fontChanged(QString font);
+     void resetFont();
+     void fontSize1Changed(int f1);
+     void fontSize2Changed(int f2);
+     void fontSize3Changed(int f3);
+     void lockScreen();
 
     signals:
      void starting();
      void finishing();
+     void changeFont();
 
     protected:
      virtual void showEvent(QShowEvent* show_pref);
